@@ -2,6 +2,7 @@ class PacktoolsError(Exception):
     """ The root of all evil in this lib.
     """
 
+
 class XMLDoctypeError(PacktoolsError, TypeError):
     """ To handle missing or unsupported DOCTYPE definitions.
     """
@@ -20,3 +21,18 @@ class UndefinedDTDError(PacktoolsError, TypeError):
 class HTMLGenerationError(PacktoolsError):
     """ Generic errors during HTML generation phase.
     """
+
+
+class SPPackageError(PacktoolsError):
+    """ Generic errors during SP Package optimisation.
+    """
+
+
+class XMLWebOptimiserError(SPPackageError):
+    """ Generic errors during XML WEB optimisation.
+    """
+
+
+class WebImageGeneratorError(SPPackageError):
+    """ Generic errors during WEB Image optimisation.
+    """
